@@ -267,7 +267,7 @@ class YouTubeDataService(object):
                 key = parts[0]
                 for p in parts[1:]:
                     idx = p.rfind(",")
-                    value = p[:idx].replace("\\/", "/")
+                    value = p[:idx].replace("\\/", "/").replace("\u0026", "&") # Quick and dirty fix
                     formats[int(key)] = value
                     key = p[idx + 1:]
                 
